@@ -24,4 +24,4 @@ os.chdir(orig_path)
 os.system("cp " + lib_path + " .")
 
 import pyseing
-from pyseing import CalculateFP
+from pyseing import CalculateFP # import doesn't work without this statement, don't know why
